@@ -1,5 +1,5 @@
 #' @title Test the effect of phylogenetic uncertainty on rate shifts found at a particular node
-#' @description The function uses a number of alternative phylogenies with altered (as compared to the reference tree) topology and branch lengths tests whether the tips descending from the specified node (\code{'node'}) have statistically different rates from the rest of the tree. A phenotypic vector \code{'y'} must be supplied. Eventually, the effect of a covariate could be included.
+#' @description The function uses a number of alternative phylogenies with altered (as compared to the reference tree) topology and branch lengths tests whether the tips descending from the specified node (\code{node}) have statistically different rates from the rest of the tree. A phenotypic vector \code{y} must be supplied. Eventually, the effect of a covariate could be included.
 #' @usage swap.phylo(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL)
 #' @param tree a phylogenetic tree. The tree needs not to be ultrametric or fully dichotomous.
 #' @param si the proportion of tips whose topologic arrangement will be swapped.
@@ -8,14 +8,14 @@
 #' @param y the phenotype under testing.
 #' @param rts the rates found by \code{\link{RRphylo}} on the original tree.
 #' @param nrep the number of simulated trees to be produced.
-#' @param cov the covariate to be indicated if its effect on rate values must be accounted for. Contrary to \code{RRphylo}, \code{'cov'} needs to be as long as the number of tips of the tree.
+#' @param cov the covariate to be indicated if its effect on rate values must be accounted for. Contrary to \code{RRphylo}, \code{cov} needs to be as long as the number of tips of the tree.
 #' @importFrom graphics hist par
 #' @importFrom grDevices rgb
 #' @importFrom stats t.test
 #' @details \code{swap.phylo} changes the tree topology and branch lengths to a level specified by the user. Up to half of the tips, and half of the branch lengths can be changed randomly. The function provides a 'swapped' tree, yet, importantly, once a shift in the rate of evolution has been found by \code{\link{RRphylo}}, this function can be used to test whether the shift depends on the tree topology and branch lengths. It runs \code{RRphylo} on swapped trees (default is 100) and then calculates the absolute rate difference between all the branches of the shifted node and the rest of the tree. A t-test is eventually performed to assess significance.
 #' @export
 #' @return The function returns a 'list' object containing:
-#' @return \strong{$p.swap} the probability that the rates at \code{'node'} are different from rates at the rest of the tree.
+#' @return \strong{$p.swap} the probability that the rates at \code{node} are different from rates at the rest of the tree.
 #' @return \strong{$rates} the distribution of rates per branch as calculated by \code{RRphylo} on 'swapped' phylogenies.
 #' @examples
 #'   data("DataApes")
@@ -41,12 +41,7 @@
 
 
 
-swap.phylo<-
-  function(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL)
-
-
-  {
-
+swap.phylo<-function(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL){
 
     maxN <- function(x, N=2){
       len <- length(x)
@@ -62,12 +57,12 @@ swap.phylo<-
     Rrts<-list()
     if(is.null(cov))
     {
-      replicate(nrep,RRphylo(swapONE(tree,si,si2)[[1]],y)$rates)->Rrts
+      replicate(nrep,RRphylo(swapONE(tree,si,si2,plot.swap=FALSE)[[1]],y)$rates)->Rrts
     }else{
       RRphylo(tree,cov)->RRcov
       c(RRcov$aces,cov)->cova
       names(cova)<-c(rownames(RRcov$aces),names(cov))
-      replicate(nrep,RRphylo(swapONE(tree,si,si2)[[1]],y,cov=cova)$rates)->Rrts
+      replicate(nrep,RRphylo(swapONE(tree,si,si2,plot.swap=FALSE)[[1]],y,cov=cova)$rates)->Rrts
     }
 
     for(i in 1:dim(Rrts)[3]) Rrts[,,i][match(rownames(rts),names(Rrts[,,i]))]
